// 这里的vm，就是我们在vue文件里面的this，所以我们能在这里获取vuex的变量，比如存放在里面的token
// 同时，我们也可以在此使用getApp().globalData，如果你把token放在getApp().globalData的话，也是可以使用的
import {
	devUrl,
	prodUrl,
	contentType,
	showLoading,
	loadingText,
	loadingTime,
	headerTokenName,
	userTokenName,
	codeName,
	successCode,
	invalidCode,
} from '@/common/settings'

const install = (Vue, vm) => {
	Vue.prototype.$u.http.setConfig({

		// baseUrl: '/api', //本地使用代理
		// downloadUrl: 'http://api.lesson.site.xmnk.cn',
		// production
		// baseUrl: 'http://lesson.site.xmnk.cn/pap/admin',
		// downloadUrl: 'http://lesson.site.xmnk.cn/pap/admin',
		// // online
		//#ifndef H5
		//除h5以外
		baseUrl: process.env.NODE_ENV === 'development' ? devUrl : prodUrl, // 请求的本域名
		//#endif
		//#ifdef H5
		//h5执行
		baseUrl: '/api',
		//#endif
		downloadUrl: '',
		originalData: true,
		dataType: 'json',
		showLoading: true, // 是否显示请求中的loading
		loadingText, // 请求loading中的文字提示
		loadingTime, // 在此时间内，请求还没回来的话，就显示加载中动画，单位ms
		loadingMask: true, // 展示loading的时候，是否给一个透明的蒙层，防止触摸穿透
		// 设置自定义头部content-type
		header: {
			'content-type': contentType,
			'device': 'weapp',
			'Accept': 'application/json',
			'Cross-Origin-Embedder-Policy': 'require-corp',
			'Cross-Origin-Opener-Policy': 'same-origin'
		}
	});
	// 请求拦截，配置Token等参数
	Vue.prototype.$u.http.interceptor.request = (config) => {
		// config.header.Token = 'xxxxxx';

		// 方式一，存放在vuex的token，假设使用了uView封装的vuex方式，见：https://uviewui.com/components/globalVariable.html
		// config.header.token = vm.token;
		// console.log(vm.vuex_token)
		config.header.Authorization = uni.getStorageSync('token');
		// config.header['Term-Id'] = vm.vuex_term_id
		// 方式二，如果没有使用uView封装的vuex方法，那么需要使用$store.state获取
		// config.header.token = vm.$store.state.token;
		// 方式三，如果token放在了globalData，通过getApp().globalData获取
		// config.header.token = getApp().globalData.username;
		// 方式四，如果token放在了Storage本地存储中，拦截是每次请求都执行的，所以哪怕您重新登录修改了Storage，下一次的请求将会是最新值
		// const token = uni.getStorageSync('token');
		// config.header.token = token;
		return config;
	}

	// 响应拦截，判断状态码是否通过
	Vue.prototype.$u.http.interceptor.response = (res) => {
		// console.log(JSON.parse(res.data))
		// 如果把originalData设置为了true，这里得到将会是服务器返回的所有的原始数据
		// 判断可能变成了res.statueCode，或者res.data.code之类的，请打印查看结果
		if (res.statusCode == invalidCode) {
			// Vue.prototype.$u.toast('登录过期请重新登录')
			// Vue.prototype.$u.vuex('vuex_token', '');
			// Vue.prototype.$u.vuex('vuex_user', '');
			// Vue.prototype.$u.vuex('vuex_id', '');
			uni.removeStorageSync('token')
			uni.removeStorageSync('lifeData')
			uni.reLaunch({
				url: '/pages/login/login'
			})
			return
		}
		if (res.statusCode == 422 || res.statusCode == 400 || res.statusCode == 500 || res.statusCode == 423 ||
			res.statusCode == 501) {
			uni.showToast({
				title: res.data.message,
				icon: 'none'
			})
			return false
		}
		if (res.statusCode < 300 && res.statusCode >= successCode) {
			// 如果把originalData设置为了true，这里return回什么，this.$u.post的then回调中就会得到什么
			return res.data;
		} else return false;
	}
}

export default {
	install
}